@@ -35,20 +35,11 @@ VAT_CLASSES_AND_RATES = [("services", "0.21"), ("goods", "0.21"), ("reduced", "0
 VatRules.clear()
 add = VatRules.add_item
 for vat_class, rate in VAT_CLASSES_AND_RATES:
-    add(vat_class,  rate, NAT,  'purchases', None,       CommonAccounts.vat_deductible)
+    add(vat_class,  rate, NAT,  'purchases', 'subject',  CommonAccounts.vat_deductible)
     add(vat_class,  rate, EU,   'purchases', 'intracom', CommonAccounts.vat_deductible, CommonAccounts.vat_returnable)
+    add(vat_class,  rate, NAT,  'purchases', 'cocontractor', CommonAccounts.vat_deductible, CommonAccounts.vat_returnable)
     add(vat_class,  rate, None, 'sales',     None,       CommonAccounts.vat_due)
 
-# add('normal',  '0.21', NAT,  'purchases', None,       CommonAccounts.vat_deductible)
-# add('reduced', '0.07', NAT,  'purchases', None,       CommonAccounts.vat_deductible)
-# add('normal',  '0.21', EU,   'purchases', 'intracom', CommonAccounts.vat_deductible, CommonAccounts.vat_returnable)
-# add('reduced', '0.07', EU,   'purchases', 'intracom', CommonAccounts.vat_deductible, CommonAccounts.vat_returnable)
-# add('normal',  '0.21', EU,   'sales',     'intracom', CommonAccounts.vat_due, CommonAccounts.vat_returnable)
-# add('reduced', '0.07', EU,   'sales',     'intracom', CommonAccounts.vat_due, CommonAccounts.vat_returnable)
-# add('normal',  '0.00', EU,   'sales',     'intracom')
-# add('reduced', '0.00', EU,   'sales',     'intracom')
-# add('normal',  '0.21', None, 'sales',     None,       CommonAccounts.vat_due)
-# add('reduced', '0.07', None, 'sales',     None,       CommonAccounts.vat_due)
 add()
 
 
