@@ -121,7 +121,10 @@ class FinancialVoucherItem(VoucherItem, SequencedVoucherItem,
 
     @dd.chooser(simple_values=True)
     def match_choices(cls, voucher, partner):
-        return cls.get_match_choices(voucher.journal, partner)
+        fkw = {}
+        if not dd.plugins.finan.suggest_future_vouchers:
+            fkw.update(value_date__lte=voucher.entry_date)
+        return cls.get_match_choices(voucher.journal, partner, **fkw)
 
     def add_item_from_due(self, obj, **kwargs):
         return self.voucher.add_item_from_due(obj, **kwargs)
@@ -151,7 +154,7 @@ class FinancialVoucherItem(VoucherItem, SequencedVoucherItem,
         if not dd.plugins.finan.suggest_future_vouchers:
             flt.update(value_date__lte=self.voucher.entry_date)
 
-        self.collect_suggestions(ar, flt)
+        self.collect_suggestions(ar, models.Q(**flt))
 
 
     def partner_changed(self, ar):
@@ -159,7 +162,9 @@ class FinancialVoucherItem(VoucherItem, SequencedVoucherItem,
         :attr:`partner`.
 
         """
-        # dd.logger.info("20160329 FinancialMixin.partner_changed")
+        # dd.logger.info("20210106 FinancialMixin.partner_changed %s", self.amount)
+        if self.amount:
+            return
         if not self.partner or not self.voucher.journal.auto_fill_suggestions:
             return
         flt = dict(partner=self.partner, cleared=False)
@@ -175,7 +180,7 @@ class FinancialVoucherItem(VoucherItem, SequencedVoucherItem,
     def collect_suggestions(self, ar, flt):
         suggestions = list(ledger.get_due_movements(
             self.voucher.journal.dc, flt))
-
+        # dd.logger.info("20210106 %s", suggestions)
         if len(suggestions) == 0:
             self.match = ""
         elif len(suggestions) == 1:
@@ -200,7 +205,13 @@ class FinancialVoucherItem(VoucherItem, SequencedVoucherItem,
             # ar.success(E.tostring(html), alert=True)
             # # ar.confirm(ok, E.tostring(html))
 
+    def amount_changed(self, ar):
+        if not self.amount:
+            self.guess_amount()
+
     def account_changed(self, ar):
+        if self.amount:
+            return
         if not self.account:
             return
         if self.account.default_amount:
@@ -208,11 +219,18 @@ class FinancialVoucherItem(VoucherItem, SequencedVoucherItem,
             # self.dc = not self.voucher.journal.dc
             # self.dc = not self.account.type.dc
             return
-        if self.voucher.auto_compute_amount:
+        if self.account.clearable and self.voucher.journal.auto_fill_suggestions:
+            flt = dict(account=self.account, partner=self.partner, cleared=False)
+            if not dd.plugins.finan.suggest_future_vouchers:
+                flt.update(value_date__lte=self.voucher.entry_date)
+            if self.match:
+                flt.update(match=self.match)
+            self.collect_suggestions(ar, models.Q(**flt))
+        elif self.voucher.auto_compute_amount:
             total = Decimal()
             for item in self.voucher.items.exclude(id=self.id):
                 total += item.amount
-            self.amount = total
+            self.amount = -total
 
 
     def get_partner(self):
@@ -309,3 +327,8 @@ class DatedFinancialVoucherItem(FinancialVoucherItem):
             obj.last_item_date = self.date
             obj.full_clean()
             obj.save()
+
+    def fill_suggestion(self, due):
+        super(DatedFinancialVoucherItem, self).fill_suggestion(due)
+        if self.voucher.last_item_date:
+            self.date = self.voucher.last_item_date
