@@ -152,10 +152,9 @@ class PaymentOrder(FinancialVoucher, Printable):
                 None, (acc, None), None, self.journal.dc, amount,
                 partner=self.journal.partner, match=self)
                 # 20191226 partner=self.journal.partner, match=self.get_default_match())
-
-        # side effect!:
-        self.full_clean()
-        self.save()
+        # no need to save() because this is called during set_workflow_state()
+        # self.full_clean()
+        # self.save()
 
     def add_item_from_due(self, obj, **kwargs):
         # if obj.bank_account is None:
@@ -216,6 +215,7 @@ class BankStatement(DatedFinancialVoucher):
         if not a:
             warn_jnl_account(self.journal)
         amount, movements_and_items = self.get_finan_movements()
+        # dd.logger.info("20210106 %s %s %s", self.balance2, self.balance1, amount)
         if self.journal.dc == DC.credit:  # 20201219 BankStatement.get_wanted_movements()
             self.balance2 = self.balance1 + amount
         else:
@@ -228,9 +228,9 @@ class BankStatement(DatedFinancialVoucher):
             yield m
         yield self.create_movement(
             None, (a, None), None, self.journal.dc, amount)
-        # side effect!:
-        self.full_clean()
-        self.save()
+        # no need to save() because this is called during set_workflow_state()
+        # self.full_clean()
+        # self.save()
 
 
 class JournalEntryItem(DatedFinancialVoucherItem):
@@ -455,15 +455,17 @@ class FillSuggestionsToVoucherItem(FillSuggestionsToVoucher):
 
     def run_from_ui(self, ar, **kw):
         i = ar.master_instance
-        voucher = i.voucher
         obj = ar.selected_rows[0]
         # i is the voucher item from which the suggestion table had
         # been called. obj is the first selected DueMovement object
-        for k, v in voucher.due2itemdict(obj).items():
-            setattr(i, k, v)
+        # dd.logger.info("20210106 %s", i)
+        i.fill_suggestion(obj)
+        # for k, v in voucher.due2itemdict(obj).items():
+        #     setattr(i, k, v)
         i.full_clean()
         i.save()
 
+        voucher = i.voucher
         seqno = i.seqno
         n = 0
         for obj in ar.selected_rows[1:]:
