@@ -144,11 +144,14 @@ class Journal(BabelNamed, Sequenced, Referrable, PrintableType):
     def get_next_number(self, voucher):
         # ~ self.save() # 20131005 why was this?
         cl = self.get_doc_model()
-        flt = dict()
+        qs = cl.objects.filter(journal=self)
         if self.yearly_numbering:
-            flt.update(accounting_period__year=voucher.accounting_period.year)
-        d = cl.objects.filter(journal=self, **flt).aggregate(
-            models.Max('number'))
+            qs = qs.filter(accounting_period__year=voucher.accounting_period.year)
+        if voucher.pk:
+            # after editing the entry_date of the last voucher of the journal we
+            # don't want its number to increase
+            qs = qs.exclude(pk=voucher.pk)
+        d = qs.aggregate(models.Max('number'))
         number = d['number__max']
         #~ logger.info("20121206 get_next_number %r",number)
         if number is None:
@@ -652,10 +655,12 @@ class Voucher(UserAuthored, Duplicable, UploadController, PeriodRangeObservable)
 
     def after_ui_save(self, ar, cw):
         super(Voucher, self).after_ui_save(ar, cw)
+        tt = self.get_trade_type()
+        if tt is None:
+            return
         p = self.get_partner()
         if p is None:
             return
-        tt = self.get_trade_type()
         account = tt.get_partner_invoice_account(p)
         if account is None:
             return
@@ -847,7 +852,7 @@ class RegistrableVoucher(Registrable, Voucher):
                 'ba': 'toggle_state'}]
 
     def after_state_change(self, ar, oldstate, newstate):
-        # movements are created *after* having changed the state, because
+        # Movements are created *after* having changed the state because
         # otherwise the match isn't correct.
         if newstate.name == 'draft':
             self.deregister_voucher(ar)
@@ -863,6 +868,9 @@ class RegistrableVoucher(Registrable, Voucher):
         # self.year = FiscalYears.get_or_create_from_date(self.entry_date)
         # dd.logger.info("20151211 movement_set.all().delete()")
 
+        # if self.number is None:
+        #     self.number = self.journal.get_next_number(self)
+
         def doit(partners):
             seqno = 0
             # dd.logger.info("20151211 gonna call get_wanted_movements()")
