@@ -467,7 +467,7 @@ class PartnerVouchers(Vouchers):
         if pv.cleared == dd.YesNo.yes:
             qs = qs.exclude(movement__cleared=False)
         elif pv.cleared == dd.YesNo.no:
-            qs = qs.filter(movement__cleared=False)
+            qs = qs.filter(movement__cleared=False, movement__account__clearable=True)
         return qs
 
 
@@ -1021,7 +1021,7 @@ class MovementsByVoucher(Movements):
     # auto_fit_column_widths = True
     display_mode = "html"
     order_by = dd.plugins.ledger.remove_dummy(
-        'value_date', 'account__ref', 'partner', 'project', 'id')
+        'seqno', 'value_date', 'account__ref', 'partner', 'project', 'id')
 
 
 class MovementsByPartner(Movements):
@@ -1083,6 +1083,9 @@ class MovementsByPartner(Movements):
 
 
 class MovementsByProject(MovementsByPartner):
+    editable = False
+    column_names = 'value_date voucher_link description \
+    debit credit match_link cleared *'
     master_key = 'project'
     display_mode = "html"
     order_by = ['-value_date', 'partner', 'id']
